#
# spec file for package telegram-desktop
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Disable LTO on TW due to build failures
%if 0%{?suse_version} > 01500
%define _lto_cflags %{nil}
%endif

# We need at least gcc8 or higher to build
%if 0%{?suse_version} < 01550 && 0%{?is_opensuse}
%bcond_without  fixed_gcc
%else
%bcond_with     fixed_gcc
%endif

%define __builder ninja

Name:           telegram-desktop
Version:        2.1.11
Release:        lp152.1.1
Summary:        Messaging application with a focus on speed and security
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
URL:            https://github.com/telegramdesktop/tdesktop
Source0:        https://github.com/telegramdesktop/tdesktop/releases/download/v%{version}/tdesktop-%{version}-full.tar.gz
# PATCH-FIX-OPENSUSE
Patch0:         0000-gtk2-default.patch
# PATCH-FIX-OPENSUSE
Patch1:         0001-use-bundled-range.patch
BuildRequires:  appstream-glib
BuildRequires:  chrpath
BuildRequires:  cmake >= 3.16
BuildRequires:  desktop-file-utils
BuildRequires:  enchant-devel
BuildRequires:  ffmpeg-devel
BuildRequires:  freetype-devel
%if %{with fixed_gcc}
BuildRequires:  gcc9-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  glibc-devel
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblz4-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  libqt5-qtimageformats-devel
BuildRequires:  memory-constraints
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  xorg-x11-devel
BuildRequires:  xxhash-devel
BuildRequires:  xz
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbusmenu-qt5)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libmng)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpcre16)
BuildRequires:  pkgconfig(libpcrecpp)
BuildRequires:  pkgconfig(libpcreposix)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libproxy-1.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-glx)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(mtdev)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(opusurl)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(portaudiocpp)
BuildRequires:  pkgconfig(tslib)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(zlib)
# Runtime requirements
Requires:       ffmpeg
Requires:       hicolor-icon-theme
Requires:       icu
Requires:       openssl
# TDesktop can fall back to a simple GTK file picker but prefers the portal
Recommends:     xdg-desktop-portal
ExclusiveArch:  x86_64

%description
Telegram is a non-profit cloud-based instant messaging service.
Users can send messages and exchange photos, videos, stickers, audio and files of any type.
Its client-side code is open-source software but the source code for recent versions is not
always immediately published, whereas its server-side code is closed-source and proprietary.
The service also provides APIs to independent developers.

%prep
%setup -q -n tdesktop-%{version}-full

%patch0 -p1
%patch1 -p1

%build
%limit_build -m 2048
%if %{with fixed_gcc}
export CC=/usr/bin/gcc-9
export CXX=/usr/bin/g++-9
%endif

%cmake \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DCMAKE_BUILD_TYPE=Release \
      -DTDESKTOP_API_ID=340630 \
      -DTDESKTOP_API_HASH=98a22f733eac40f1bd187a30d19271de \
      -DDESKTOP_APP_USE_GLIBC_WRAPS=OFF \
      -DDESKTOP_APP_USE_PACKAGED=ON \
      -DDESKTOP_APP_USE_PACKAGED_GSL=OFF \
      -DDESKTOP_APP_USE_PACKAGED_EXPECTED=OFF \
      -DDESKTOP_APP_USE_PACKAGED_RLOTTIE=OFF \
      -DDESKTOP_APP_USE_PACKAGED_VARIANT=OFF \
      -DTDESKTOP_USE_PACKAGED_TGVOIP=OFF \
      -DDESKTOP_APP_USE_PACKAGED_FONTS=ON \
      -DDESKTOP_APP_DISABLE_CRASH_REPORTS=ON \
      -DTDESKTOP_DISABLE_AUTOUPDATE=ON \
      -DTDESKTOP_LAUNCHER_BASENAME=%{name} \
      -DDESKTOP_APP_SPECIAL_TARGET=""

%cmake_build

%install
%cmake_install

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml

%files
%license LICENSE LEGAL
%doc README.md changelog.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/metainfo/*.appdata.xml

%changelog
* Mon Jun  8 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.11
  * Fix launching on old Linux systems.
* Fri Jun  5 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- update to 2.1.10
  * Improve memory usage.
  * Add support for full group message history export.
  * Allow export of a single chat message history in JSON format.
* Wed Jun  3 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.8 (beta)
  * Add support for full group message history export.
  * Allow export of a single chat message history in JSON format.
- Rebased 0000-gtk2-default.patch
* Sun May 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.7
  * Fix the Fcitx input method plugin.
* Wed May 13 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.5
  * Disable the taskbar icon flash or the dock icon bounce in
    Settings > Notifications.
  * View messages containing long monospace texts in wide bubbles.
  * Bug fixes and other minor improvements.
- rebased 0001-use-bundled-range.patch
* Sat May  9 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.4
  * Improve bold font selection.
* Fri May  8 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.3
  * Added support for new emoji.
  * Channels to which you can't post will no longer be suggested
    when forwarding.
  * Improved font selection and bold font support for CJK and Farsi.
  * Fix polls and quizes results viewing.
  * Fix memory leak in web page previews with autoplayed videos.
  * Fix running on OS X 10.10.
  * Other minor bug fixes and improvements.
- removed range-v3-master.zip, range is now bundled in the
  upstream source
- rebased 0001-use-bundled-range.patch
* Sat May  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.1.1
  * Improve quiz explanation tooltip layout.
  * Fix possible crash in theme editor.
  * Other minor bug fixes and improvements.
- Remove 0002-fix-directory-open-via-portals.patch
  * this release already contains the fix
* Sat Apr 25 2020 Markus S <kamikazow@opensuse.org>
- Update to 2.1.0
  * Access a catalog of over 20,000 stickers made by professional
    artists from the updated Sticker Panel by clicking the '+' icon.
  * Use sticker search to find the stickers you're looking for
    or scroll from the latest packs all the way to the classics.
  * Add explanations that appear after users respond to a quiz question.
  * See how much time you have left to answer a question from
    @QuizBot with the new countdown animation.
  * Send a single :dart: emoji to see if you hit the bullseye.
- Disable libdee requirement after Python2 removal
- Upstream recommends using xdg-desktop-portal, so we might do the same
- Add 0002-fix-directory-open-via-portals.patch
  * Upstream fix for a bug when opening directories via portals
* Tue Mar 31 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.0.1
  * Switch between folders using Ctrl+1, ..., Ctrl+8.
  * Fix crash when a pinned in folder chat was added to archive.
  * Fix font issues in Linux version.
* Mon Mar 30 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.0.0
  * Organize chats into Chat Folders if you have too many chats.
  * Create custom folders with flexible settings, or use default
    recommendations.
  * Pin an unlimited number of chats in each folder.
  * Switch between folders in the new side bar to easily access
    all of your chats.
  * Send :dice: to any chat to try your luck and get a random number
    from the animated dice.
  * Send :virus:, :face_with_thermometer:, :mask:,
    :face_with_head_bandage:, :sneeze:, :sick:, :soap: or :ambulance:
    to try out the new animated emoji.
* Tue Mar 17 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.21
  * Mark new messages as read while scrolling down through them.
  * Improved spellchecking on Windows 7 and Linux.
  * Fix crash in shared links search.
  * Fix blurred thumbnails in albums with video files.
  * Fix a possible crash in animated stickers rendering.
  * Bug fixes and other minor improvements.
* Tue Feb 18 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.14
  * Bug fixes and other minor improvements.
* Wed Feb 12 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.13
  * Bug fixes and other minor improvements.
* Tue Feb 11 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.12
  * Switch to the Picture-in-Picture mode to watch your video in a
    small window.
  * Change video playback speed in the playback controls '...' menu.
  * Rotate photos and videos in the media viewer using the rotate
    button in the bottom right corner.
* Wed Jan 29 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.9
  * Bug fixes and other minor improvements.
- Removed 0002-use-bundled-rlottie.patch,
  there's a cmake switch for this
- Add cmake version requirement
* Fri Jan 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.8
  * Bug fixes and other minor improvements.
* Thu Jan 23 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.7
  * Create three new kinds of polls.
  * See who voted for what in polls with visible votes.
  * Vote for several options in polls that allow multiple answers.
  * Guess the correct answer in quiz-style polls.
  * Explore various ways of combining the different poll options.
  * Add polls from the '...' menu in any group or channel.
  * Use bots like @quizbot to create quizzes with several questions
    and media attachments.
  * Schedule messages to be sent when your recipient comes online
    (only works if you know their online status).
- Clean up spec file
* Wed Jan 22 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.6
  * Bug fixes and other minor improvements.
- Removed 0005-Use-system-wide-fonts.patch and
  0006-Revert-Disable-DemiBold-fallback-for-Semibold.patch,
  option to use system fonts added upstream
* Fri Jan 17 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.9.4
  * Bug fixes and other minor improvements.
- Removed patches, option to use distribution libraries
  added upstream:
  * 0001-Dynamic-linking-system-libs.patch
  * 0002-Dynamic-linking-system-qt.patch
  * 0004-gtk3.patch
- Added patches for dependencies not available from repos:
  * 0001-use-bundled-range.patch
  * 0002-use-bundled-rlottie.patch
* Thu Jan 16 2020 Xu Zhao <i@xuzhao.net>
- Upgrade to 1.9.3
  * Videos in chats start playing automatically.
  * Resume playback from where you left off when watching long
    videos and listening to long audio tracks.
  * Control automatic playback for videos, GIFs and round video
    messages in Settings > Advanced > Automatic media download.
  * Enjoy system spell checker support on all modern systems.
- Switch build system to Ninja
- Rename default-gtk2.patch to 0000-gtk2-default.patch,
  removed tdesktop.patch
- Added patches:
  * 0001-Dynamic-linking-system-libs.patch
  * 0002-Dynamic-linking-system-qt.patch
  * 0004-gtk3.patch
  * 0005-Use-system-wide-fonts.patch
  * 0006-Revert-Disable-DemiBold-fallback-for-Semibold.patch
* Tue Nov  5 2019 Xu Zhao <i@xuzhao.net>
- Remove the TDESKTOP_DISABLE_GTK_INTEGRATION macro in patch.py
  * Enable the native notification on all platforms.
- Add default-gtk2.patch: Use GTK 2 theme by default to harmonize
  the libqt5-prioritise-gtk2-platformtheme.patch (boo#1149986)
  in libqt5-qtbase.
* Sat Nov  2 2019 Xu Zhao <i@xuzhao.net>
- Update to 1.8.15
  * Bug fixes and other minor improvements.
* Sat Sep 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.9
  * Bug fixes and other minor improvements.
* Tue Sep 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.8
  * Create new themes based on your color and wallpaper choices.
  * Share your themes with other users via links.
  * Update your theme for all its users when you change something.
* Tue Sep 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.7 (beta)
  * Bug fixes and other minor improvements.
- Disable GTK integration again due to Cinnamon hard requiring
  libqt5-qtstyleplugins-platformtheme-gtk2 (boo#1149130)
* Mon Sep  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.5 (beta)
  * Create new themes based on your color and wallpaper choices.
  * Share your themes with other users via links.
  * Update your theme for all its users when you change something.
* Fri Sep  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.4
  * Bug fixes and other minor improvements.
- Updated rlottie
* Fri Sep  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.3
  * Right click the 'Send' button and select 'Schedule Message'
    to automatically send something at a specified time.
  * Schedule reminders for yourself in the 'Saved Messages' chat.
  * Get a notification when any of your scheduled messages are sent.
  * Customize your app's appearance by choosing accent colors for
    the 'Day', 'Night' and 'Tinted' themes.
  * Choose who can find you on Telegram when they add your number
    to their phone contacts.
  * Send a single :grin:, :anguished:, :rage:, :poo:, :cry:
    or :open_mouth: to check out what's new in the animated
    emoji department.
* Wed Aug 21 2019 mvetter@suse.com
- bsc#1146555 - Drop jasper dependency from telegram-desktop:
  Remove JPEG2000 support due to removal of libjasper
* Tue Aug 20 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.2
  * Bug fixes and other minor improvements.
- Enable GTK integration for native notifications, this only works
  when libqt5-qtstyleplugins-platformtheme-gtk2 is absent
  - > introducing Conflicts with that Package
* Sat Aug 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.1
  * Bug fixes and other minor improvements.
* Fri Aug  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.8.0
  * Right click the Send button to send any message without sound -
    in case the recipient is sleeping.
  * Enable Slow Mode in Group Permissions to control how frequently
    members can post.
  * Set custom titles for group admins - like 'Founder', 'CFO' or
    'Spam Fighter'.
  * Toggle looped playback for animated stickers in Chat Settings.
  * Send a single :heart:, :like:, :unamused:, :flushed: or :party:
    to add a mighty animated emoji to the chat.
- Updated crl and rlottie
* Fri Jul 19 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.15
  * Bug fixes and other minor improvements.
- Allow GCC 9 after GCC#90949 was fixed
- Updated rlottie
* Sun Jul  7 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.13
  * Send ultra-lightweight high-quality animated stickers to
    express emotion with motion.
  * Receive animated stickers instantly on any connection at
    just 20-30 KB per sticker.
  * Enjoy smooth animations at 60 frames per second.
  * Create new animated sets and upload them to @stickers for
    everybody to use.
  * Try out these sample stickers: t.me/addstickers/hotcherry
  * Use strikethrough and underline formatting.
- Removed rapidjson and qtlottie, added rlottie and lz4, updated crl
- Disable LTO due to build failures
* Mon Jun 24 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.10
  * Bug fixes and other minor improvements.
- Updated libtgvoip and qtlottie
* Sun Jun 23 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.9
  * You can now add any users to your contacts, even if their phone
    numbers are not visible.
  * Transfer ownership of group chats and channels by granting full
    rights to another admin. Useful when switching jobs or if you
    just want to retire as creator.
  * Hide archived chats to the main menu.
  * See who is online straight from the chat list.
  * Use the MacBook Pro TouchBar to apply formatting to
    selected text, insert emoji, and send stickers.
- switch to ayatana-appindicator3-0.1
* Tue Jun 18 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.8
  * Hide archived chats in the main menu.
  * See who is online straight from the chat list.
  * Apply formatting to selected text parts from the
    MacBook Pro TouchBar.
* Mon Jun 10 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.7
  * Bug fixes and other minor improvements.
* Thu Jun  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.6
  * Bug fixes and other minor improvements.
- Updated qtlottie
* Wed Jun  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Keep using GCC8 on Tumbleweed until there is a resolution for
  https://github.com/telegramdesktop/tdesktop/issues/5996
* Wed Jun  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.5
  * Download video files while watching them using streaming.
  * Set EOL for Windows XP / Vista and OS X 10.6 to 10.9
    at September 1.
  * Crash fix.
- Remove gcc7-fix.patch because GCC7 will no longer work due to
  qtlottie requiring "class-memaccess" option
* Wed Jun  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.3
  * Bug fixes and other minor improvements.
- New 3rd party: rapidjson
* Sat Jun  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.2
  * Choose who can see your phone number with granular precision in
    Privacy & Security settings.
  * Add group chats to "Always/Never Share" exceptions for any
    privacy setting. Permissions will update as users leave
    and join the groups.
  * Connect a discussion group to your channel, subscribers will
    see a "Discuss" button.
  * Integrate bots seamlessly with web services.
    For example, see t.me/DiscussThis/1
  * Use TouchBar on MacBooks Pro to control music playback and
    switch between pinned chats.
- New 3rd party: qtlottie
* Thu May 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Updated bundled 3rd party sources to fix gcc9 build failures
  * breakpad, linux-syscall-support, gyp, crl to current master
  * libtgvoip to v2.4.4
  * mapbox-variant to v1.1.6
  * range-v3 to v0.5.0
  * xxHash to v0.7.0
- spec-cleaner: use pkconfig
* Thu May  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.7.0
- Introducing Archived Chats:
  * Archive any chat from the right-click menu.
  * Chats with enabled notifications will pop out of the archive
    when a notification arrives.
  * Muted chats will stay in the archive.
  * Pin an unlimited number of chats in your archive.
* Sat Apr 13 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.7
  * Replace media when editing messages with media content.
  * Jump quickly to the top of your chats list.
  * Get emoji suggestions for the first word you type in a message.
  * Help Telegram improve emoji suggestions in your language using
    this interface https://translations.telegram.org/en/emoji
* Thu Apr 11 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.6
  * Bug fixes and other minor improvements.
* Sat Apr  6 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.5
  * Bug fixes and other minor improvements.
* Fri Apr  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.4
  * Replace media when editing messages with media content.
  * Jump quickly to the top of your chats list.
  * Get emoji suggestions for the first word you type in a message.
  * Help Telegram improve emoji suggestions in your language using
    this interface https://translations.telegram.org/en/emoji
* Sun Mar 24 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.2
  * Delete any message on both ends in any private chat, anytime.
  * Control whether your forwarded messages link back to your account.
  * Control who may see your profile picture.
  * Enjoy the new streamlined group management screen.
* Wed Mar 20 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.6.1
  * Play video files and listen to received music without
    waiting for them to download.
  * Press CTRL+0 (CMD+0 on macOS) to jump to your Saved Messages.
  * Bug fixes and other minor improvements.
- Apply gcc7-fix patch on Leap 15.0 only
* Thu Feb 21 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Do not apply gcc7-fix.patch on Tumbleweed
* Wed Feb 20 2019 ramaxlo@gmail.com
- Fix build failure for openSUSE Leap 15.0.
* Tue Feb 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.15
  * Crash fix.
* Tue Feb 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.13
  * Bug fixes and other minor improvements.
* Sat Feb  9 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.12
  * Apply blur effects to backgrounds.
  * Use the backgrounds you set in Telegram Desktop in all other Telegram apps.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.11
  * Bug fixes and other minor improvements.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.10
  * Bug fixes and other minor improvements.
* Fri Feb  1 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.9
  * Bug fixes and other minor improvements.
* Tue Jan 22 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.8
  * Global permissions for groups. Restrict all members in any
    group from posting certain types of content.
  * Unified group settings. Make groups public, set admins with
    granular permissions and toggle persistent history in just a
    few clicks in any group.
  * Choose the emoji set you would like to use in Chat Settings.
  * Choose input and output devices for Telegram Calls in
    Settings > Advanced > Call Settings.
  * Support for automatically downloading files and music.
* Fri Jan 11 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.5.4
  * Bug fixes and other minor improvements.
  * Create polls in groups and channels - right from the chat menu.
* Thu Jan 10 2019 Ramax Lo <ramaxlo@gmail.com>
- Add TDESKTOP_DISABLE_OPENAL_EFFECTS to fix playback error:
  Audio Playback Error: 40963, Invalid Value
* Sat Dec 22 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.5.2
  * Bug fixes and other minor improvements.
  * Support for custom languages.
  * Interface scaling for large screens.
  * Video messages displayed in shared media.
* Sat Nov 17 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.4.7
  * Crash fix.
  * Bug fixes and other minor improvements
  * Listen to voice and video messages in 2X mode if you're in a hurry.
  * Find video messages in the shared voice messages section.
  * Add a comment when you share posts from channels.
  * View all photos and videos in Twitter and Instagram link previews.
  * Interface scaling for large screens, up to 300%% (up to 150%% for macOS retina screens).
  * Updated emoji.
- Add api_id and api_hash to build
* Thu Oct 11 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.4.2
  * Crash fix.
  * Reduce crashes due to the out of memory exceptions.
  * Load map previews through mtproto.
  * Bug fixes and other minor improvements.
  * Fully redesigned Settings section.
  * New theme selector in Chat Settings.
  * New local storage settings: Control how much disk space is used by the cache and for how long the cached files are stored.
  * Improved local caching for images and GIF animations.
  * New settings: Peer-to-Peer settings for calls, disable animations for low performance computers.
  * Various other improvements.
* Tue Sep 18 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid repeating name in summary.
* Mon Sep  3 2018 Xu Zhao <i@xuzhao.net>
- Update to 1.3.15
  * Improved local files cache.
  * Move to use kservices5.
* Fri Jul 27 2018 i@xuzhao.net
- Update to 1.3.10
  * Bug fixes adn other minor improvements.
- Changes in 1.3.9
  * Mark chats in the chat list as Read or Unread.
  * Improved censorship circumvention.
* Sat Jun  2 2018 duyizhaozj321@yahoo.com
- Update to 1.3.0
  * Improved censorship circumvention.
  * Improved stability when working through proxy servers.
  * Save several proxy servers to quickly switch between them in Settings.
  * Use proxy for calls.
  * Emoji and text replacement now happens immediately after typing (instead of after sending) and can
    be rolled back using Backspace or CTRL/CMD + Z. Replacement no longer happens when pasting text.
- Changes in 1.2.25
  * Apply markdown formatting (```, `, **, __) only when sending the message.
  * Display connection quality bars in calls.
  * Telegram Desktop can update itself through MTProto.
  * Bug fixes and other minor improvements.
* Sun May 27 2018 duyizhaozj321@yahoo.com
- Update to 1.2.24
  * Add links with custom text from context menu or by Ctrl/Cmd + K keyboard shortcut.
* Sat May 26 2018 duyizhaozj321@yahoo.com
- Update to 1.2.23
  * Apply formatting from input field context menu.
  * Apply formatting by hotkeys.
  * Bug fixes and other minor improvements.
* Fri May 25 2018 i@xuzhao.net
- Update to 1.2.22
  * Use markdown in media captions (bold, italic, tag and code).
  * Use emoji replacement in media captions, group and channel titles and descriptions (:like: etc.)
  * Markdown replacement now happens immediately after typing (instead of after sending) and can be rolled back using Backspace or Ctrl/Cmd + Z.
    Replacement no longer happens when pasting text.
* Mon Apr 16 2018 ilya@ilya.pp.ua
- Update to 1.2.17
  * Bug fixes and other minor improvements.
* Wed Mar 28 2018 ilya@ilya.pp.ua
- Update to 1.2.15
  * Discover new stickers. Type one emoji to see suggestions from
    popular sticker sets. Suggestions from your installed sticker
    sets will come first.
  * Search for Stickers. Click on the new search icon to access
    your sticker sets or find new ones.
  * Use fast reply button in group chats.
  * Select a message you want to reply to by pressing Ctrl+Up and
    Ctrl+Down.
* Tue Mar 20 2018 ilya@ilya.pp.ua
- Refresh spec-file via spec-cleaner and manual optimizations.
  * Add %%license and %%doc macros.
  * Remove Leap/SLE support for version < 15.
  * Increment to 4 GB of RAM for a more stable build.
  * Change Description and Summary.
* Mon Feb 26 2018 badshah400@gmail.com
- Use -a instead of -b to \%%setup to fix buing on openSUSE >=
  1500; this behaviour changed with rpm 4.14.
- Add BuildRequires: python2-base as python2 executable is needed
  for gyp scripts. It was being automatically pulled in for
  Factory, but not for Leap:15.0.
* Fri Jan 12 2018 badshah400@gmail.com
- Add Requires: libqt5-qtimageformats; required to show images of
  any kind (emoji, stickers, etc.) in the interface since the
  switch to system Qt5.
* Sun Dec 31 2017 badshah400@gmail.com
- Update to version 1.2.6:
  * Grouped Photos: Group media into an album when sharing
    multiple photos and videos. Choose the exact order of media
    you send.
  * Bug fixes and other minor improvements.
- Add crl-master.zip from https://github.com/telegramdesktop/crl
  and copy it to build dir appropriately; this is now required
  for building.
- Rebase tdesktop.patch.
* Mon Dec 18 2017 badshah400@gmail.com
- Update to version 1.2.1:
  * Bug fixes and other minor improvements.
* Fri Dec 15 2017 badshah400@gmail.com
- update patch.py to remove dee-1.0 dependency, which is not in
  use any more, and not available from factory, thus resolving
  unresolvable status.
* Wed Dec 13 2017 badshah400@gmail.com
- Update minimal versions of gcc and cmake in BuildRequires in
  keeping with upstream: gcc >= 7 (7.2) is now needed. Also update
  the gcc command exported before building on openSUSE <= 1320 to
  gcc-7.
* Mon Dec 11 2017 badshah400@gmail.com
- Update to version 1.2.0:
  * Radically improved navigation. New side panel on the right
    with quick access to shared media and group members.
  * Saved Messages. Bookmark messages by forwarding them to "Saved
    Messages". Access them from the Chats list or from the side
    menu.
  * Pinned Messages. If you are a channel admin, pin messages to
    focus your subscribers' attention on important announcements.
  * Easily recognize messages from group admins by the new 'admin'
    badge.
  * Also supported clearing history in supergroups and added a
    host of minor improvements.
- Disable parallel make for main app because the build job becomes
  terribly slow, and eventually runs out of memory otherwise.
* Fri Sep  8 2017 badshah400@gmail.com
- Update to version 1.1.23:
  * See the message author photo and name while searching specific
    chat messages.
  * Fix "Send To" menu action on Windows.
- Rebase and rename patch-1.1.19.diff to patch-1.1.23.diff.
- Add catch.hpp as source and copy to required dir; remove
  includes referring to subdirs of catch as we are using the one
  header version.
- Refresh all third-party sources to their current versions.
- Add breakpad-ucontext_t-glibc2_26.patch: Replace
  `struct ucontext` by `ucontext_t` to make breakpad compatible
  with glib-2.26; merged upstream as commit e3035bc; only apply
  for openSUSE > 1320.
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 1.1.19:
  * Search by messages of specific group members.
  * Bug fixes and other minor improvements.
- Update name of patch-1.1.18.diff to patch-1.1.19.diff (no
  rebase was needed).
* Thu Jul 27 2017 badshah400@gmail.com
- Update to version 1.1.18:
  * Minor bug fixes.
- Update name of patch-1.1.17.diff to patch-1.1.18.diff (no
  rebase was needed).
* Wed Jul 26 2017 badshah400@gmail.com
- Update to version 1.1.17:
  * Minor bug fixes.
- Update to version 1.1.16:
  * Autocompletion for emoji. Start typing :e to get suggestions.
  * Fixed a bug with forwarding messages.
- Update patch-1.1.15.diff to patch-1.1.17.diff (minor rebase).
* Mon Jul 24 2017 badshah400@gmail.com
- Update to version 1.1.15:
  * Send bold and italic text in your messages.
  * Get a share link for posts in public supergroups.
  * Quickly share posts from channels and media messages from
    bots.
  * Search large supergroup members by name.
  * Search channel members by name for admins.
  * Use search in the service actions log.
  * Ban supergroup members via the right click menu in the service
    actions log.
- Update name of patch-1.1.10.diff to patch-1.1.15.diff (no
  rebase was needed).
* Tue Jul 11 2017 badshah400@gmail.com
- Use post(un) scriptlets to update hicolor icon-theme cache, and
  the desktop database; without these the desktop menu icon does
  not get registered to the icon and picks up a default ugly icon,
  until subsequent installation of other programs or manual
  invocation of the commands corresponding to these scriptlets.
* Sat Jul  8 2017 badshah400@gmail.com
- Update to version 1.1.10:
  * Add event log filter for channel or supergroup event log.
  * Fix search by username in privacy exceptions editor.
  * Fix adding admins in channels.
* Sun Jul  2 2017 badshah400@gmail.com
- Update to version 1.1.9:
  * Supergroups can now have up to 10.000 members.
  * Appoint supergroup admins with granular rights. Choose who can
    add users, manage messages, block members, edit group info &
    username, add new admins, etc.
  * Restrict and ban supergroup members with granular precision.
    Read-only bans, GIF & sticker bans, media bans, temporary bans
    and restrictions.
  * Check the new event log to see all service actions taken by
    members and admins of a channel or supergroup in the last 48
    hours.
  * Toggle night mode in the main menu.
- Rebase patch-%%{version}.diff for updated version.
- Enforce strict version dependence for BuildRequires on
  libtelegram-qt5-devel-static = 5.6.2, since telegram does not
  build with older versions any more. Pass -Dqt_version="5.6.2"
  instead of -Dqt_version="5.6.0" when configuring for build with
  gyp.
* Wed Jun 21 2017 badshah400@gmail.com
- For openSUSE Leap, use gcc6 from the Update repository (gcc6
  from OSS is uninstallable).
- Add a _constraints file to restrict building to hardware with at
  2 GB of physical memory.
* Sun Jun  4 2017 badshah400@gmail.com
- Update to version 1.1.7.
- Add libtgvoip.zip to sources, required to build Telegram
- Rebase patch-1.0.29.diff for updated version; rename to
  patch-%%{version}.diff.
- New BuildRequires: pkgconfig(libpulse), pkgconfig(alsa); needed
  to build Telegram with audio/video support.
* Sun Apr 30 2017 badshah400@gmail.com
- Update to version 1.0.29.
- Use full URL for telegram-desktop source.
- Require gcc-c++ >= 5.0, since support for -std=gnu++14 is now
  required; on openSUSE versions <= 1320 using gcc5 or gcc6
  nonetheless leads to build failures.
- Update icon file name in keeping with upstream.
- Rebase patch-1.0.24.diff for updated version; rename it to
  patch-1.0.29.diff.
* Mon Jul 18 2016 badshah400@gmail.com
- Add %%post scriptlets to update icon theme cache and desktop
  database (BuildRequires: hicolor-icon-theme, Requires(post):
  desktop-file-utils).
- Use full URL for source.
- Run through spec-cleaner to clean up spec file according to
  openSUSE guidelines.
* Mon Jul  4 2016 i@xuzhao.net
- Upgrade to 0.9.56
- Fixed photo viewer to handle screen resolution change correctly.
- Fixed forwarding photos via drag-n-drop.
- Various design improvements and other bug fixes.
* Mon May 16 2016 i@xuzhao.net
- 0.9.48 Initial Commit.
